Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Field ¶
type Field byte
Field is the type of field being collected
type Sample ¶
type Sample struct {
BatchNumber int
Began time.Time
Ended time.Time
Solved bool
Generations int
Evaluations int
Seconds float64
Values map[Field]map[Method]float64
}
Sample is the result of an evaluation run
type Sampler ¶
type Sampler struct {
// contains filtered or unexported fields
}
Sampler records the results of an experiment's run
func NewSampler ¶
NewSampler creates a new efficacy sampler
func (*Sampler) Callbacks ¶
Callbacks returns a new listener callback function for the given batch number.
func (*Sampler) Close ¶
Close the underlying writer returning any error from that action
Source Files
¶
- sampler.go
Click to show internal directories.
Click to hide internal directories.